==> haskell-authenticate-1.3.5.2-18-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-HyMAvdtbljDLZhIUU4g7o
key:                  authenticate-1.3.5.2-HyMAvdtbljDLZhIUU4g7o
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  30d4dc894c879832c54c5df9d951fa60
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.2.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-HyMAvdtbljDLZhIUU4g7o
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn
    attoparsec-aeson-2.1.0.0-D2SWchNoil66qsxvPlcd3h base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf
    conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s containers-0.6.5.1
    html-conduit-1.3.2.2-6VKmfRDRxnvQvsgZw2yzj
    http-conduit-2.3.8.3-1nsQ6LY8l6ZCKHc2yiI82m
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    network-uri-2.6.4.2-7MCOm8Y28rz5TXDrjTesz4
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa
    xml-conduit-1.9.1.3-78hprMCLgMFFWPQU2FN158

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.5.2-43-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-2pGXSdLI437D26eJYsxNZm
key:                  authenticate-1.3.5.2-2pGXSdLI437D26eJYsxNZm
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  96151199ef1dace8e8eb4c33f348bf9c
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.2.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-2pGXSdLI437D26eJYsxNZm
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq
    attoparsec-aeson-2.1.0.0-Dv7oW4CsUXjKQqMNZaLFPh base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x containers-0.6.5.1
    html-conduit-1.3.2.2-3IUsEAE0avc6ithdSPc59g
    http-conduit-2.3.8.3-KkBMXrBtxP6LrN8a2mfNMZ
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    network-uri-2.6.4.2-H8R7YZM4iJL108zVnRjrHh
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    xml-conduit-1.9.1.3-AwLhlaz27ql1567v7tH4L6

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
